%% Function Line Search
%% Finds approximation of Y: argmin f(xi + tau*d)
%% Input:
%%	fun - function hanler
%%	dir - direction of search
%%	xi  - starting search point
%%	delta - accuracy. By default is 0.001
%%	beta - multiplyer. By default is 0.9
%% Output:
%%	y - approximated value of step-width
%% Comment: This is not very fair backtracking line search.
%%	this line fun(xi+tau*dir) > old_f-delta*tau*dir'*dir
%% 	has to look like this fun(xi+tau*dir) > old_f+delta*tau*dir'*grad(f),
%%	but since we concider dir = -grad(f), it holds.

function y = LS(fun, dir, xi, delta = 0.0001, beta = 0.9)
	tau = 1.0; %% set to one at first
	old_f = fun(xi); %% keep the value of function in point xi
	while (fun(xi+tau*dir) > old_f-delta*tau*dir'*dir) %% armijo condition
		tau*=beta; %% make the step size smaller
	endwhile
	y = tau; %% save result
